import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Colors for the sections in Pie Chart
const sectionColors = [
  		'pink', 'white', 'red','blue','yellow', 'lime', 'green','orange','turquoise'
		  ];

// Data set URI
const csvUrl = 'https://gist.githubusercontent.com/BVNPK001/38829d528d080038d237a37770755bea/raw/9b332b88267c1d1b6ad19c103bbf998da2e66f94/marks';

// Fetching data from the URL
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

// Select the SVG from the HTML body
const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

// Formatting the axes
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Visualizing Pie Chart
const render = (data, total) => {
  const pieData = pie().value(d=>d.Marks)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // Generating Arcs of the sections
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  // Segments are the partition in the Pie Chart
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.Marks));
  
  //text on each section
  sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.Marks))+"%")
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  
  //legend for the data
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // Formats the legend for Deaths
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Marks));
  
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Marks))+"%");
  
  // Formats the legend for Countries 
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Name);
  
}

const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Marks = +d.Marks;
    total += d.Marks
  });
	render(data,total);
};
run();